searchData={"content_type":"text/markdown","items":[{"doc":"Avalanche is an Elixir [Snowflake](https://docs.snowflake.com/en/developer-guide/sql-api/index.html) Connector built on top of the Snowflake SQL API v2.","ref":"Avalanche.html","title":"Avalanche","type":"module"},{"doc":"* Submit SQL statements for execution.\n\n* Check the status of the execution of a statement.\n\n* Cancel the execution of a statement.\n\n* Manage your deployment (e.g. provision users and roles, create tables, etc.)","ref":"Avalanche.html#module-features","title":"Features - Avalanche","type":"module"},{"doc":"```elixir\ndef deps do\n  [\n    {:avalanche, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"Avalanche.html#module-installation","title":"Installation - Avalanche","type":"module"},{"doc":"List of available Req request options.\n\nSee `Req.request/1` for more information.","ref":"Avalanche.html#available_req_options/0","title":"Avalanche.available_req_options/0","type":"function"},{"doc":"Returns default options.\n\nSee `default_options/1` for more information.","ref":"Avalanche.html#default_options/0","title":"Avalanche.default_options/0","type":"function"},{"doc":"Sets default options.\n\nThe default options are used by `run/2` functions.\n\nAvoid setting default options in libraries as they are global.","ref":"Avalanche.html#default_options/1","title":"Avalanche.default_options/1","type":"function"},{"doc":"Submits SQL statements to Snowflake for execution.\n\n  * `:statement` - the SQL statement that you want to execute\n\n  * `:params` - list of values for the bind variables in the statement\n\n#### Run Options\n\n* `:async` (`t:boolean/0`) - Set to true to execute the statement asynchronously and return the statement handle. The default value is `false`.\n\n* `:request_id` (`t:String.t/0`) - Unique ID (a UUID) of the API request.\n\n* `:retry` (`t:boolean/0`) - Set to true only when retrying the statement with a previous `request_id`.\n\n\n\n#### Request Options\n\n* `:server` (`t:String.t/0`) - Required. Snowflake server to send requests to.\n\n* `:warehouse` (`t:String.t/0`) - Required. Snowflake warehouse for the statement execution.\n\n* `:database` (`t:String.t/0`) - Required. Snowflake database for the statement execution.\n\n* `:schema` (`t:String.t/0`) - Required. Snowflake schema for the statement execution.\n\n* `:role` (`t:String.t/0`) - Required. Snowflake role for the statement execution.\n\n* `:timeout` (`t:non_neg_integer/0`) - Snowflake timeout in seconds for the statement execution. 0 to 604800 (i.e. 7 days) — a value of 0 specifies that the maximum timeout value is enforced. The default value is `3600`.\n\n* `:token` - Required. Snowflake authentication via OAuth token (string) or Key Pair (Keyword List): \n\n     * `:account` (`t:String.t/0`) - Snowflake Account ID\n\n    * `:user` (`t:String.t/0`) - User\n\n    * `:priv_key` (`t:String.t/0`) - RSA Private Key\n\n* `:poll` (non-empty `t:keyword/0`) - Options to customize polling for the completion of a statement's execution. Synchronous statement execution will wait a maximum of 45 secondes plus the `poll` configuration (75 seconds) for a total of 2 minutes. The default value is `[delay: 2500, max_attempts: 30]`.\n\n  * `:delay` (`t:pos_integer/0`) - Sleep this number of milliseconds between attempts.\n\n  * `:max_attempts` (`t:pos_integer/0`) - Maximum number of poll attempts.\n\n* `:get_partitions` (non-empty `t:keyword/0`) - Options to customize retrieving all the partitions of data from a statement's execution. The default value is `[timeout: 120000]`.\n\n  * `:max_concurrency` (`t:pos_integer/0`) - Sets the maximum number of tasks to run at the same time. The default value is `System.schedulers_online/0`.\n\n  * `:timeout` (`t:pos_integer/0`) - Maximum amount of time to wait (in milliseconds).\n\n* `:decode_data` (non-empty `t:keyword/0`) - Options to customize how data is decoded from a statement's execution. The default value is `[downcase_column_names: false]`.\n\n  * `:downcase_column_names` (`t:boolean/0`) - Downcase the result's column names.\n\n* `:receive_timeout` (`t:pos_integer/0`) - Finch socket receive timeout in milliseconds.\n  The default accounts for Snowflake's 45 second synchronous statement execution timeout.\n  Use the `poll` options if you want to wait longer for a result. Otherwise a statement handle\n  will be returned that you can use with `Avalanche.status/3` to get the result. The default value is `50000`.\n\n\n\nThe `request_options` are merged with default options set with `default_options/1`.","ref":"Avalanche.html#run/4","title":"Avalanche.run/4","type":"function"},{"doc":"Checks the status of a statement execution.\n\n  * `:statement_handle` - the unique identifier for an executed statement\n\n#### Status Options\n\n* `:async` (`t:boolean/0`) - Set to true to disable polling and waiting for a statement to finish executing. The default value is `false`.\n\n* `:partition` (`t:non_neg_integer/0`) - Number of the partition of results to return. The number can range from 0 to the total number of partitions minus 1. The default value is `0`.\n\n\n\n#### Request Options\n\n* `:server` (`t:String.t/0`) - Required. Snowflake server to send requests to.\n\n* `:warehouse` (`t:String.t/0`) - Required. Snowflake warehouse for the statement execution.\n\n* `:database` (`t:String.t/0`) - Required. Snowflake database for the statement execution.\n\n* `:schema` (`t:String.t/0`) - Required. Snowflake schema for the statement execution.\n\n* `:role` (`t:String.t/0`) - Required. Snowflake role for the statement execution.\n\n* `:timeout` (`t:non_neg_integer/0`) - Snowflake timeout in seconds for the statement execution. 0 to 604800 (i.e. 7 days) — a value of 0 specifies that the maximum timeout value is enforced. The default value is `3600`.\n\n* `:token` - Required. Snowflake authentication via OAuth token (string) or Key Pair (Keyword List): \n\n     * `:account` (`t:String.t/0`) - Snowflake Account ID\n\n    * `:user` (`t:String.t/0`) - User\n\n    * `:priv_key` (`t:String.t/0`) - RSA Private Key\n\n* `:poll` (non-empty `t:keyword/0`) - Options to customize polling for the completion of a statement's execution. Synchronous statement execution will wait a maximum of 45 secondes plus the `poll` configuration (75 seconds) for a total of 2 minutes. The default value is `[delay: 2500, max_attempts: 30]`.\n\n  * `:delay` (`t:pos_integer/0`) - Sleep this number of milliseconds between attempts.\n\n  * `:max_attempts` (`t:pos_integer/0`) - Maximum number of poll attempts.\n\n* `:get_partitions` (non-empty `t:keyword/0`) - Options to customize retrieving all the partitions of data from a statement's execution. The default value is `[timeout: 120000]`.\n\n  * `:max_concurrency` (`t:pos_integer/0`) - Sets the maximum number of tasks to run at the same time. The default value is `System.schedulers_online/0`.\n\n  * `:timeout` (`t:pos_integer/0`) - Maximum amount of time to wait (in milliseconds).\n\n* `:decode_data` (non-empty `t:keyword/0`) - Options to customize how data is decoded from a statement's execution. The default value is `[downcase_column_names: false]`.\n\n  * `:downcase_column_names` (`t:boolean/0`) - Downcase the result's column names.\n\n* `:receive_timeout` (`t:pos_integer/0`) - Finch socket receive timeout in milliseconds.\n  The default accounts for Snowflake's 45 second synchronous statement execution timeout.\n  Use the `poll` options if you want to wait longer for a result. Otherwise a statement handle\n  will be returned that you can use with `Avalanche.status/3` to get the result. The default value is `50000`.\n\n\n\nThe `request_options` are merged with default options set with `default_options/1`.","ref":"Avalanche.html#status/3","title":"Avalanche.status/3","type":"function"},{"doc":"Prepares bindings from list of values.\n\nhttps://docs.snowflake.com/en/developer-guide/sql-api/submitting-requests.html#using-bind-variables-in-a-statement","ref":"Avalanche.Bindings.html","title":"Avalanche.Bindings","type":"module"},{"doc":"Encodes the given values into an indexed map of bindings.\n\nExamples:\n\n    iex> values = [123, 1.23, \"uno, dos, tres\", false, ~N[2015-01-14 13:00:07], DateTime.from_unix!(1_464_096_368), ~D[2015-01-15]]\n    iex> Avalanche.Bindings.encode_params(values)\n    %{\n      \"1\" => %{type: \"FIXED\", value: \"123\"},\n      \"2\" => %{type: \"REAL\", value: \"1.23\"},\n      \"3\" => %{type: \"TEXT\", value: \"uno, dos, tres\"},\n      \"4\" => %{type: \"BOOLEAN\", value: false},\n      \"5\" => %{type: \"TEXT\", value: \"2015-01-14T13:00:07\"},\n      \"6\" => %{type: \"TEXT\", value: \"2016-05-24T13:26:08Z\"},\n      \"7\" => %{type: \"TEXT\", value: \"2015-01-15\"}\n    }","ref":"Avalanche.Bindings.html#encode_params/1","title":"Avalanche.Bindings.encode_params/1","type":"function"},{"doc":"Context for JWTs","ref":"Avalanche.JWTs.html","title":"Avalanche.JWTs","type":"module"},{"doc":"","ref":"Avalanche.JWTs.html#create_signer/2","title":"Avalanche.JWTs.create_signer/2","type":"function"},{"doc":"","ref":"Avalanche.JWTs.html#generate_claims/2","title":"Avalanche.JWTs.generate_claims/2","type":"function"},{"doc":"","ref":"Avalanche.JWTs.html#peek_claims/1","title":"Avalanche.JWTs.peek_claims/1","type":"function"},{"doc":"","ref":"Avalanche.JWTs.html#peek_header/1","title":"Avalanche.JWTs.peek_header/1","type":"function"},{"doc":"","ref":"Avalanche.JWTs.html#sign/2","title":"Avalanche.JWTs.sign/2","type":"function"},{"doc":"","ref":"Avalanche.JWTs.JWTBehaviour.html","title":"Avalanche.JWTs.JWTBehaviour","type":"behaviour"},{"doc":"","ref":"Avalanche.JWTs.JWTBehaviour.html#c:create_signer/2","title":"Avalanche.JWTs.JWTBehaviour.create_signer/2","type":"callback"},{"doc":"","ref":"Avalanche.JWTs.JWTBehaviour.html#c:generate_claims/2","title":"Avalanche.JWTs.JWTBehaviour.generate_claims/2","type":"callback"},{"doc":"","ref":"Avalanche.JWTs.JWTBehaviour.html#c:peek_claims/1","title":"Avalanche.JWTs.JWTBehaviour.peek_claims/1","type":"callback"},{"doc":"","ref":"Avalanche.JWTs.JWTBehaviour.html#c:peek_header/1","title":"Avalanche.JWTs.JWTBehaviour.peek_header/1","type":"callback"},{"doc":"","ref":"Avalanche.JWTs.JWTBehaviour.html#c:sign/2","title":"Avalanche.JWTs.JWTBehaviour.sign/2","type":"callback"},{"doc":"Delegates to Joken (https://github.com/joken-elixir/joken)\n\nWe ignore test coverage here because this is tested by the :integration test we have setup.\n\nWe don't run :integration tests in CI, so we are ignoring the report here.","ref":"Avalanche.JWTs.JWTJokenImpl.html","title":"Avalanche.JWTs.JWTJokenImpl","type":"module"},{"doc":"Request helpers.","ref":"Avalanche.Request.html","title":"Avalanche.Request","type":"module"},{"doc":"","ref":"Avalanche.Request.html#build_headers/2","title":"Avalanche.Request.build_headers/2","type":"function"},{"doc":"","ref":"Avalanche.Request.html#fetch_token/1","title":"Avalanche.Request.fetch_token/1","type":"function"},{"doc":"","ref":"Avalanche.Request.html#server_url/1","title":"Avalanche.Request.server_url/1","type":"function"},{"doc":"","ref":"Avalanche.Request.html#statements_path/0","title":"Avalanche.Request.statements_path/0","type":"function"},{"doc":"The Result struct returned from any successful query.\n\n\nFields:\n\n* `:status` - the status of the statement being executed (`:running`, `:complete`)\n\n* `:statement_handle` - the unique identifier for the statement being executed.\nIf multiple statements were specified in the request, this handle corresponds\nto the set of those statements.\n\n* `:statement_handles` - list of unique identifiers for the statements being executed for this request.\n\n* `:num_rows` - the number of fetched or affected rows\n\n* `:rows` - the result set. A list of maps with, each inner map corresponding to a\nrow and each element in the map corresponds to a column.","ref":"Avalanche.Result.html","title":"Avalanche.Result","type":"module"},{"doc":"","ref":"Avalanche.Result.html#t:result_status/0","title":"Avalanche.Result.result_status/0","type":"type"},{"doc":"","ref":"Avalanche.Result.html#t:t/0","title":"Avalanche.Result.t/0","type":"type"},{"doc":"The execute statement request struct.\n\nStruct fields:\n\n  * `:url` - the HTTP request URL (e.g. https://account-id.snowflakecomputing.com)\n\n  * `:headers` - the HTTP request headers\n\n  * `:body` - the HTTP request body\n\n  * `:token` - the HTTP Bearer authentication token\n\n  * `:options` - options to customize HTTP pipeline steps","ref":"Avalanche.StatementRequest.html","title":"Avalanche.StatementRequest","type":"module"},{"doc":"Builds a statement execution request to run.","ref":"Avalanche.StatementRequest.html#build/3","title":"Avalanche.StatementRequest.build/3","type":"function"},{"doc":"Runs a statement execution request.\n\nReturns `{:ok, response}` or `{:error, exception}`.","ref":"Avalanche.StatementRequest.html#run/2","title":"Avalanche.StatementRequest.run/2","type":"function"},{"doc":"","ref":"Avalanche.StatementRequest.html#t:body/0","title":"Avalanche.StatementRequest.body/0","type":"type"},{"doc":"","ref":"Avalanche.StatementRequest.html#t:t/0","title":"Avalanche.StatementRequest.t/0","type":"type"},{"doc":"","ref":"Avalanche.StatementRequest.html#t:url/0","title":"Avalanche.StatementRequest.url/0","type":"type"},{"doc":"The check query status request struct.\n\nStruct fields:\n\n  * `:url` - the HTTP request URL (e.g. https://account-id.snowflakecomputing.com)\n\n  * `:path` - the HTTP request path.\n\n  * `:headers` - the HTTP request headers.\n\n  * `:body` - the HTTP request body.\n\n  * `:token` - the HTTP Bearer authentication token.\n\n  * `:row_types` - an array of objects that describe the columns in the set of results. used for decoding.\n\n  * `:options` - options to customize HTTP pipeline steps","ref":"Avalanche.StatusRequest.html","title":"Avalanche.StatusRequest","type":"module"},{"doc":"Builds a query status request to run.","ref":"Avalanche.StatusRequest.html#build/3","title":"Avalanche.StatusRequest.build/3","type":"function"},{"doc":"Runs a query status request.\n\nReturns `{:ok, response}` or `{:error, exception}`.","ref":"Avalanche.StatusRequest.html#run/3","title":"Avalanche.StatusRequest.run/3","type":"function"},{"doc":"","ref":"Avalanche.StatusRequest.html#t:row_types/0","title":"Avalanche.StatusRequest.row_types/0","type":"type"},{"doc":"","ref":"Avalanche.StatusRequest.html#t:t/0","title":"Avalanche.StatusRequest.t/0","type":"type"},{"doc":"","ref":"Avalanche.StatusRequest.html#t:url/0","title":"Avalanche.StatusRequest.url/0","type":"type"},{"doc":"A custom `Req` pipeline step to decode the `body.data` returned by Snowflake.","ref":"Avalanche.Steps.DecodeData.html","title":"Avalanche.Steps.DecodeData","type":"module"},{"doc":"Decodes response `body.data` based on the `resultSetMetaData`.\n\nhttps://docs.snowflake.com/en/developer-guide/sql-api/reference.html#label-sql-api-reference-resultset-resultsetmetadata","ref":"Avalanche.Steps.DecodeData.html#attach/2","title":"Avalanche.Steps.DecodeData.attach/2","type":"function"},{"doc":"* `:downcase_column_names` - Downcase the result's column names.","ref":"Avalanche.Steps.DecodeData.html#attach/2-options","title":"Options - Avalanche.Steps.DecodeData.attach/2","type":"function"},{"doc":"","ref":"Avalanche.Steps.DecodeData.html#decode_data/1","title":"Avalanche.Steps.DecodeData.decode_data/1","type":"function"},{"doc":"A custom `Req` pipeline step to retrieve all the partitions of data from a statement execution.","ref":"Avalanche.Steps.GetPartitions.html","title":"Avalanche.Steps.GetPartitions","type":"module"},{"doc":"Get partitioned data per the `resultSetMetaData`.\n\nhttps://docs.snowflake.com/en/developer-guide/sql-api/reference.html#label-sql-api-reference-resultset-resultsetmetadata","ref":"Avalanche.Steps.GetPartitions.html#attach/2","title":"Avalanche.Steps.GetPartitions.attach/2","type":"function"},{"doc":"* `:max_concurrency` - sets the maximum number of tasks to run at the same time.\n    Defaults to `System.schedulers_online/0`.\n\n  * `:timeout` - the maximum amount of time to wait (in milliseconds). Defaults to 2 minutes.","ref":"Avalanche.Steps.GetPartitions.html#attach/2-options","title":"Options - Avalanche.Steps.GetPartitions.attach/2","type":"function"},{"doc":"","ref":"Avalanche.Steps.GetPartitions.html#get_partitions/1","title":"Avalanche.Steps.GetPartitions.get_partitions/1","type":"function"},{"doc":"A custom `Req` pipeline step to poll for the completion of an asynchronous or long (> 45 seconds) query.","ref":"Avalanche.Steps.Poll.html","title":"Avalanche.Steps.Poll","type":"module"},{"doc":"Polls for the completion of a statement execution if async is false.\n\n  * `:request` - the request\n\n  * `:disable` - set to true to disable polling for this request","ref":"Avalanche.Steps.Poll.html#attach/3","title":"Avalanche.Steps.Poll.attach/3","type":"function"},{"doc":"* `:delay` - sleep this number of milliseconds between attempts, defaults to `1000`\n\n  * `:max_attempts` - maximum number of poll attempts, defaults to `5` (for a total of `5`\n    requests to the server, including the initial one.)","ref":"Avalanche.Steps.Poll.html#attach/3-options","title":"Options - Avalanche.Steps.Poll.attach/3","type":"function"},{"doc":"","ref":"Avalanche.Steps.Poll.html#poll/1","title":"Avalanche.Steps.Poll.poll/1","type":"function"},{"doc":"Telemetry integration.\n\nUnless specified, all time's are in `:native` units.\n\nAvalanche executes the following events:","ref":"Avalanche.Telemetry.html","title":"Avalanche.Telemetry","type":"module"},{"doc":"`[:avalanche, :query, :start]` - Executed at the start of each query sent to Snowflake.\n\n#### Measurements\n\n  * `:system_time` - The time the query started\n\n#### Metadata:\n\n  * `:query` - The query sent to the database as a string\n  * `:params` - The query parameters","ref":"Avalanche.Telemetry.html#module-query-start","title":"Query Start - Avalanche.Telemetry","type":"module"},{"doc":"`[:avalanche, :query, :stop]` - Executed at the end of each query sent to Snowflake.\n\n#### Measurements\n\n  * `:duration` - The time spent executing the query\n\n#### Metadata:\n\n  * `:query` - The query sent to the database as a string\n  * `:params` - The query parameters\n  * `:result` - The query result (selected, updated)\n  * `:num_rows` - The number of rows effected by the query\n  * `:error` - Present if any error occurred while processing the query. (optional)","ref":"Avalanche.Telemetry.html#module-query-stop","title":"Query Stop - Avalanche.Telemetry","type":"module"},{"doc":"`[:avalanche, :query, :exception]` - Executed if executing a query throws an exception.\n\n#### Measurements\n\n  * `:duration` - The time spent executing the query\n\n#### Metadata\n\n  * `:kind` - The type of exception.\n  * `:error` - Error description or error data.\n  * `:stacktrace` - The stacktrace","ref":"Avalanche.Telemetry.html#module-query-exception","title":"Query Exception - Avalanche.Telemetry","type":"module"},{"doc":"Used for reporting generic events","ref":"Avalanche.Telemetry.html#event/3","title":"Avalanche.Telemetry.event/3","type":"function"},{"doc":"Emits a `start` telemetry event","ref":"Avalanche.Telemetry.html#start/3","title":"Avalanche.Telemetry.start/3","type":"function"},{"doc":"Emits a stop event","ref":"Avalanche.Telemetry.html#stop/4","title":"Avalanche.Telemetry.stop/4","type":"function"},{"doc":"","ref":"Avalanche.Telemetry.TelemetryDispatchBehaviour.html","title":"Avalanche.Telemetry.TelemetryDispatchBehaviour","type":"behaviour"},{"doc":"Dispatches a telemetry event","ref":"Avalanche.Telemetry.TelemetryDispatchBehaviour.html#c:execute/3","title":"Avalanche.Telemetry.TelemetryDispatchBehaviour.execute/3","type":"callback"},{"doc":"Wrapper around `:telemetry`","ref":"Avalanche.Telemetry.TelemetryDispatchImpl.html","title":"Avalanche.Telemetry.TelemetryDispatchImpl","type":"module"},{"doc":"Token handling and caching.\n\nWill create and cache a token (`KEYPAIR_JWT`) from a private key and details or cache a given token (`OAUTH`).\n\nSee: https://docs.snowflake.com/en/developer-guide/sql-api/authenticating.html","ref":"Avalanche.TokenCache.html","title":"Avalanche.TokenCache","type":"module"},{"doc":"","ref":"Avalanche.TokenCache.html#child_spec/1","title":"Avalanche.TokenCache.child_spec/1","type":"function"},{"doc":"Fetches token from the cache or creates and caches token from given options.\n\nReturns `{\"KEYPAIR_JWT\", token}` or `{\"OAUTH\", token}`.","ref":"Avalanche.TokenCache.html#fetch_token/1","title":"Avalanche.TokenCache.fetch_token/1","type":"function"},{"doc":"","ref":"Avalanche.TokenCache.html#start_link/1","title":"Avalanche.TokenCache.start_link/1","type":"function"},{"doc":"","ref":"Avalanche.TokenCache.html#token_from_options/1","title":"Avalanche.TokenCache.token_from_options/1","type":"function"},{"doc":"Common application error.","ref":"Avalanche.Error.html","title":"Avalanche.Error","type":"exception"},{"doc":"Builds an Error struct with a reason of `:application_error`.\n\nExamples:\n    iex> alias Avalanche.Error\n    iex> Error.application_error(\"Bad Things\", %{data: \"things\"})\n    %Error{__exception__: true, message: \"Bad Things\", meta: %{data: \"things\"}, reason: :application_error}","ref":"Avalanche.Error.html#application_error/2","title":"Avalanche.Error.application_error/2","type":"function"},{"doc":"Formats a Error for printing/logging.\n\nThis returns a verbose, multi-line string.\n\nExamples:\n\n    iex> alias Avalanche.Error\n    iex> RuntimeError.exception(\"Failed!\") |> Error.new() |> Error.format()\n    ~s \n    iex> \"Failed!\" |> Error.new() |> Error.format()\n    ~s \n    iex> 123 |> Error.new() |> Error.format() =~ ~r/original_error: 123/\n    true\n    iex> :bad |> Error.new() |> Error.format() =~ ~r/bad/\n    true","ref":"Avalanche.Error.html#format/1","title":"Avalanche.Error.format/1","type":"function"},{"doc":"Builds an Error struct with reason and message deived from the given http status.\n\nExamples:\n    iex> alias Avalanche.Error\n    iex> Error.http_status(404, %{data: \"things\"})\n    %Error{__exception__: true, message: \"Not Found\", meta: %{data: \"things\"}, reason: :not_found}","ref":"Avalanche.Error.html#http_status/2","title":"Avalanche.Error.http_status/2","type":"function"},{"doc":"Returns the Error message.\n\nExamples:\n\n    iex> alias Avalanche.Error\n    iex> error = Error.application_error(\"Bad Things\", %{data: \"things\"})\n    iex> Error.message(error)\n    \"application_error: Bad Things\"","ref":"Avalanche.Error.html#message/1","title":"Avalanche.Error.message/1","type":"function"},{"doc":"Creates a new Error from a message string or another error\n\nExamples:\n\n    # A string will be used as message\n    iex> alias Avalanche.Error\n    iex> Error.new(\"These are the error message\")\n    %Error{message: \"These are the error message\"}\n    # Error structs are returned unchanged\n    iex> Error.new(%Error{reason: :some_reason})\n    %Error{reason: :some_reason}\n    # Atoms will be used as reason\n    iex> Error.new(:some_reason)\n    %Error{reason: :some_reason}\n    # Anything else will be used as the `original_error`\n    iex> Error.new(%RuntimeError{message: \"oops!\"})\n    %Error{message: \"oops!\", original_error: %RuntimeError{message: \"oops!\"}}","ref":"Avalanche.Error.html#new/1","title":"Avalanche.Error.new/1","type":"function"},{"doc":"Builds an Error struct.\n\nExamples:\n\n    iex> alias Avalanche.Error\n    iex> Error.new(:bad, \"Bad Things\", %{data: \"things\"})\n    %Error{__exception__: true, message: \"Bad Things\", meta: %{data: \"things\"}, reason: :bad}","ref":"Avalanche.Error.html#new/3","title":"Avalanche.Error.new/3","type":"function"},{"doc":"","ref":"Avalanche.Error.html#t:meta/0","title":"Avalanche.Error.meta/0","type":"type"},{"doc":"The exception type","ref":"Avalanche.Error.html#t:t/0","title":"Avalanche.Error.t/0","type":"type"}],"producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}